@@ -4,7 +4,7 @@ import numpy as np
 def _k_min(distances: np.array, k: int):
   """ Finds k-closest neighbours
 
-  For each node, returns the distance of the k-closest neighbours.
+  For each node, returns the distances of the k-closest neighbours.
 
   Parameters
   ----------
@@ -18,8 +18,4 @@ def _k_min(distances: np.array, k: int):
   -------
   - N by k numpy array
   """
-  return np.take_along_axis(
-    distances,
-    np.argpartition(distances, k-1, axis = 1)[:, :k],
-    axis = 1
-  )
+  return np.partition(distances, k, axis=1)[:, :k+1]
