@@ -25,4 +25,4 @@ def knn_distance(distances, k: int = 5):
   N by 1 numpy array containing the vertex distance values.
   """
   distances = _validation.distances_dense(distances)
-  return _k_min(distances, k)[:, k-1]
+  return _k_min(distances, k-1)[:, k-1]
